@@ -14,7 +14,7 @@ serialize a object
 """
 
 
-VERSION = '0.2.9'
+VERSION = '0.2.13'
 TOO_DEEP = 'TOO_DEEP'
 
 
@@ -29,9 +29,19 @@ def obj_to_dict(obj, *filter_fields, **kwargs):
 
     filter_fields = list(filter_fields) + list(kwargs.get('filter_fields', []))
     exclude_fields = kwargs.get('exclude_fields', [])
-    limit_deep = kwargs.get('limit_deep', 5)
+    limit_deep = kwargs.get('limit_deep', 10)
     prune = kwargs.get('prune', False)
 
+    if isinstance(obj, SerializeableObject):
+        if not filter_fields:
+            filter_fields = obj.default_filter_fields()
+        if not exclude_fields:
+            exclude_fields = obj.default_exclude_fields()
+
+    # 当指定了 filter_fields 时，exclude_fields 不生效
+    if filter_fields:
+        exclude_fields = []
+
     current_deep = kwargs.get('current_deep', 0)  # 当前递归深度(程序自己维护,不要手动传入!)
 
     if limit_deep and limit_deep < current_deep:
@@ -40,11 +50,14 @@ def obj_to_dict(obj, *filter_fields, **kwargs):
 
     kwargs['current_deep'] = current_deep + 1
 
-    # 可被序列化的类型
-    serializeable_types = six.integer_types + six.string_types + (six.text_type,)
+    # 可直接被序列化的类型
+    serializeable_types = six.integer_types + six.string_types + (six.text_type, )
     
     # 无法被序列化的类型
     disserializeable_types = (six.binary_type,)
+    
+    if obj is None:
+        return None
 
     if isinstance(obj, serializeable_types):
         return obj
@@ -123,7 +136,6 @@ serialize = obj_to_dict
 
 
 class SerializeableObject(object):
-    
 
     def serialize(self, *filter_fields, **kwargs):
         return obj_to_dict(self, *filter_fields, **kwargs)
@@ -134,6 +146,12 @@ class SerializeableObject(object):
     def to_json(self, *filter_fields, **kwargs):
         return obj_to_json(self, *filter_fields, **kwargs)
 
+    def default_filter_fields(self):
+        return []
+
+    def default_exclude_fields(self):
+        return []
+
 
 
 if __name__ == '__main__':
